pub enum InstrumentKind {
Counter,
UpDownCounter,
Histogram,
ObservableCounter,
ObservableUpDownCounter,
Gauge,
ObservableGauge,
}Expand description
The identifier of a group of instruments that all perform the same function.
Variants
Counter
Identifies a group of instruments that record increasing values synchronously with the code path they are measuring.
UpDownCounter
A group of instruments that record increasing and decreasing values synchronously with the code path they are measuring.
Histogram
A group of instruments that record a distribution of values synchronously with the code path they are measuring.
ObservableCounter
A group of instruments that record increasing values in an asynchronous callback.
ObservableUpDownCounter
A group of instruments that record increasing and decreasing values in an asynchronous callback.
Gauge
a group of instruments that record current value synchronously with the code path they are measuring.
ObservableGauge
a group of instruments that record current values in an asynchronous callback.